<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:sc="http://www.utc.fr/ics/scenari/v3/core" 
	xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive"
	xmlns:dk="kelis.fr:dokiel"
	xmlns:redirect="com.scenari.xsldtm.xalan.lib.Redirect" 
	xmlns:java="http://xml.apache.org/xslt/java" 
	extension-element-prefixes="redirect"
	xmlns:xalan="http://xml.apache.org/xalan"
	exclude-result-prefixes="xalan">
	<xsl:output encoding="UTF-8" method="xml"/>
	<xsl:param name="pCurrentItemUri"/>
	<xsl:param name="pWspPath"/>
	
	<xsl:template match="/*">
		<xsl:copy>
			<xsl:apply-templates select="@*|node()"/>
		</xsl:copy>
	</xsl:template>
	
	<!--	
		<xsl:variable name="vNewExt">nex</xsl:variable>
		<xsl:variable name="vOldUri" select="."/>
		<xsl:attribute name="sc:refUri">
		<xsl:value-of select="java:com.scenari.m.co.ant.MigrateXslTask.replaceExtension($vOldUri, $vNewExt)"/>
		</xsl:attribute>
	-->
	
	<!-- ### 
		# Retourne le local-name() du modèle fils (internalisé ou externalisé)
		### -->
	<xsl:template name="tGetSubModelType">
		<xsl:choose>
			<xsl:when test="@sc:refUri"><!-- item externalisé -->
				<xsl:value-of select="local-name(document(concat($pWspPath,'/',@sc:refUri))/*/*[1])"/>
			</xsl:when>
			<xsl:otherwise><!-- item internalisé -->
				<xsl:value-of select="local-name(*[1])"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<!-- ###
		# Permet de remplir le fichier de traces des traitements
		### -->
	<xsl:template name="tShowMessage">
		<xsl:param name="pMessage"/>
		<xsl:param name="pLevel"/><!-- [warning|error] -->
		<xsl:variable name="vPrefix">
			<xsl:choose>
				<xsl:when test="$pLevel='warning'">- ATTENTION : </xsl:when>
				<xsl:when test="$pLevel='error'">- ERREUR : </xsl:when>
				<xsl:otherwise>- </xsl:otherwise>
			</xsl:choose><xsl:text>[</xsl:text><xsl:value-of select="$pCurrentItemUri"/><xsl:text>] </xsl:text>
		</xsl:variable>
		<redirect:write file="{$pTraceFilePath}" append="true"><log><xsl:value-of select="concat($vPrefix, $pMessage)"/></log></redirect:write>
	</xsl:template>
	
	
	<!-- ###
		# Quand on passe de Content à Comment.model mode: contentToComment
		# ne change rien en ce qui concerne les bi, mais extrait les procedures, concepts, 
		# écrans et parties lorsque ceux-ci étaient internalisés
		### -->
	
	<xsl:template match="sp:infobloc | sp:warning | sp:advice | sp:tip | sp:example | sp:note | sp:legal | sp:complement" mode="contentToComment">
		<xsl:copy>
			<xsl:apply-templates select="@*|node()"/>
		</xsl:copy>
	</xsl:template>
	
	<xsl:template match="sp:op | sp:def | sp:window | sp:part " mode="contentToComment">
		<xsl:variable name="vFilePathAlt">
			<xsl:value-of select="concat($pWspPath,'/',$pCurrentItemUri, '.', generate-id(), '.unit')"/>
		</xsl:variable>
		<xsl:variable name="vFileUriAlt">
			<xsl:value-of select="concat('/',$pCurrentItemUri, '.', generate-id(), '.unit')"/>
		</xsl:variable>
		<xsl:choose>
			<xsl:when test="@sc:refUri">
				<xsl:call-template name="tShowMessage">
					<xsl:with-param name="pMessage">La balise '<xsl:value-of select="local-name(document(concat($pWspPath,'/',@sc:refUri))/*/*[1])"/>' n'a pu être récupérée. </xsl:with-param>
					<xsl:with-param name="pLevel" select="'warning'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="tShowMessage">
					<xsl:with-param name="pMessage">La balise '<xsl:value-of select="local-name(*[1])"/>' n'a pu être récupérée. 
						Le contenu n'est cependant pas perdu et se trouve dans le fichier <xsl:value-of select="$vFileUriAlt"/> </xsl:with-param>
					<xsl:with-param name="pLevel" select="'warning'"/>
				</xsl:call-template>
				<redirect:write file="{$vFilePathAlt}" append="true">
					<sc:item xmlns:sc="http://www.utc.fr/ics/scenari/v3/core">
						<xsl:apply-templates />
					</sc:item>
				</redirect:write>
			</xsl:otherwise>
		</xsl:choose>	
	</xsl:template>
	
	
	
	
	<!-- ### 
		# Cas général : on copie
		### -->
	<xsl:template match="@*|node()">
		<xsl:copy>
			<xsl:apply-templates select="@*|node()"/>
		</xsl:copy>
	</xsl:template>
	
</xsl:stylesheet>
