<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" 
		xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
		xmlns:sc="http://www.utc.fr/ics/scenari/v3/core" 
		xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive"
		xmlns:sfm="http://www.utc.fr/ics/scenari/v3/filemeta"
		xmlns:dk="kelis.fr:dokiel"
		xmlns:pw="scpf.org:presWsp"
		xmlns:xalan="http://xml.apache.org/xalan"
		exclude-result-prefixes="sc sp xalan pw">
	<xsl:output encoding="UTF-8" method="xml"/>
	
	<xsl:param name="pCurrentItemUri"/>
<!--	<xsl:param name="vDialog"/>-->
<!--	<xsl:param name="vAgent"/>-->
	
<!--	<xsl:template match="/*">
		<xsl:copy>
			<xsl:apply-templates select="@*|node()"/>
		</xsl:copy>
	</xsl:template>-->
	
	
	<!-- part.model -->
	<xsl:template match="dk:part">
		<dk:part>
			<xsl:choose>
				<xsl:when test="dk:sTitle">
					<xsl:apply-templates select="dk:sTitle" mode="toRTitle"/>
				</xsl:when>
				<xsl:otherwise>
					<dk:rTitle/>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:apply-templates select="sp:co"/>
		</dk:part>
	</xsl:template>
	
	<!-- content.model 1/3, comment.model 1/2 -->
	<xsl:template match="dk:content | dk:comment">
		<xsl:copy>
			<xsl:apply-templates select="sp:*" mode="addMetas"/>
		</xsl:copy>
	</xsl:template>
	
	<!-- startTrain.model 1/2 -->
	<xsl:template match="dk:startTrain ">
		<dk:startTrain>
			<xsl:choose>
				<xsl:when test="dk:title">
					<xsl:apply-templates select="dk:title" mode="toOptHTitle"/>
				</xsl:when>
				<xsl:otherwise>
					<dk:optHTitle/>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:apply-templates select="sp:objectives | sp:agenda | sp:block" mode="addMetas"/>
			<xsl:apply-templates select="sp:trainNote"/>
		</dk:startTrain>
	</xsl:template>
	
	<!-- logistics.model 1/2 -->
	<xsl:template match="dk:logistics ">
		<dk:logistics>
			<xsl:apply-templates select="dk:title" mode="toHeadTitle"/>
			<xsl:apply-templates select="sp:agenda | sp:block" mode="addMetas"/>
			<xsl:apply-templates select="sp:trainNote"/>
		</dk:logistics>
	</xsl:template>



			<!-- content 2/3, comment, startTrain, logistics 2/2 -->
			<xsl:template match="sp:objectives | sp:agenda | sp:block | sp:infobloc | sp:warning | sp:advice | sp:tip | sp:example | sp:note | sp:legal | sp:complement" mode="addMetas">
				<xsl:copy>
					<xsl:choose>
						<xsl:when test="dk:sTitle">
							<xsl:apply-templates select="dk:sTitle" mode="toBlocTi"/>
						</xsl:when>
						<xsl:otherwise>
							<dk:blocTi>
								<sp:filters><dk:filter/></sp:filters>
							</dk:blocTi>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:apply-templates select="dk:flowAll"/>
				</xsl:copy>
			</xsl:template>
			
			<!-- content 3/3 -->
			<xsl:template match="sp:part | sp:op | sp:def | sp:screen" mode="addMetas">
				<xsl:variable name="vRefUri"><xsl:value-of select="@sc:refUri"/></xsl:variable>
				<xsl:copy>
					<xsl:if test="$vRefUri">
						<xsl:attribute name="sc:refUri" ><xsl:value-of select="$vRefUri"/></xsl:attribute>
					</xsl:if>					
					<dk:filter />
					<xsl:apply-templates select="dk:*"/>
				</xsl:copy>
			</xsl:template>
	
	
	<!-- linkSection 1/3 -->
	<xsl:template match="dk:linkSection">
		<dk:linkSection>
			<dk:rTitle>
				<xsl:for-each select="dk:sTitle">
					<sp:rTitle>
						<dk:richTitle>
							<sc:para xml:space="preserve"><xsl:value-of select="sc:fullTitle"/></sc:para>
						</dk:richTitle>
					</sp:rTitle>
				</xsl:for-each>
			</dk:rTitle>
			<xsl:apply-templates select="sp:ref | sp:doc" mode="fromLinkSecInSec"/>
		</dk:linkSection>
	</xsl:template>
	
			<!-- linkSection 2/3 -->
			<xsl:template match="sp:ref" mode="fromLinkSecInSec">
				<xsl:copy>
					<xsl:apply-templates select="@*|node()"/>
				</xsl:copy>
			</xsl:template>
			
			<!-- linkSection 3/3 -->
			<xsl:template match="sp:doc" mode="fromLinkSecInSec">
				<sp:doc sc:refUri="{@sc:refUri}">
					<xsl:apply-templates select="dk:sTitle" mode="toRTitle" />
				</sp:doc>
			</xsl:template>
	
	
	
	<!-- stepList -->
	<xsl:template match="dk:stepList">
		<dk:stepList>
			<!-- les métas sont obligatoires -->
			<dk:stepListM>
			<xsl:for-each select="dk:sTitle">
				<sp:title>
					<dk:headTitle>
						<sp:sTitle><xsl:value-of select="sc:fullTitle"/></sp:sTitle>
					</dk:headTitle>
				</sp:title>
			</xsl:for-each>				
			</dk:stepListM>
			<xsl:apply-templates select="sp:intro | sp:overview | sp:step | sp:desc | sp:comment" />
			<xsl:apply-templates select="sp:alt" mode="fromStepList"/>
		</dk:stepList>
	</xsl:template>
	
	<xsl:template match="sp:alt" mode="fromStepList">
		<sp:alt sc:refUri="{@sc:refUri}">
			<xsl:for-each select="dk:linkM">
				<xsl:choose>
					<xsl:when test="sp:linkTi/dk:para">
						<dk:rTitle>
							<sp:rTitle>
								<dk:richTitle>
									<xsl:apply-templates select="sp:lnkTi/dk:para/*"/>
								</dk:richTitle>
							</sp:rTitle>
						</dk:rTitle>
					</xsl:when>
					<xsl:otherwise>
						<dk:rTitle />
					</xsl:otherwise>
				</xsl:choose>
				
				
			</xsl:for-each>
		</sp:alt>
	</xsl:template>

	
	<!-- step.model -->
	<xsl:template match="sp:extras[parent::dk:step]">
		<sp:extras>
			<dk:rTitle>
				<xsl:for-each select="dk:sTitle">
					<sp:rTitle>
						<dk:richTitle>
							<sc:para xml:space="preserve"><xsl:value-of select="sc:fullTitle"/></sc:para>
						</dk:richTitle>
					</sp:rTitle>
				</xsl:for-each>
			</dk:rTitle>
<!--			<xsl:apply-templates select="dk:sTitle" mode="toRTitle"/>-->
			<xsl:apply-templates select="dk:comment"/>
		</sp:extras>
	</xsl:template>


	<!-- screen -->
	<xsl:template match="dk:screenMeta">
		<dk:screenMeta>
			<xsl:if test="sp:title">
				<sp:title>
					<dk:headTitle>
						<sp:sTitle>
							<xsl:value-of select="sp:title"/>
						</sp:sTitle>
					</dk:headTitle>
				</sp:title>
			</xsl:if>
		</dk:screenMeta>
	</xsl:template>

	<!-- section.model -->
	<xsl:template match="dk:section">
		<dk:section>
			<xsl:apply-templates select="dk:title" mode="toHeadTitle"/>
			<xsl:apply-templates select="sp:*"/>
		</dk:section>
	</xsl:template>
	
	
	
	
	
	
	
	
	
	<!-- userGuide.model -->	
	<xsl:template match="dk:userGuide">
		<dk:userGuide>
			<dk:headTitle>
				<sp:sTitle><xsl:value-of select="dk:userGuideM/sp:title"/></sp:sTitle>
			</dk:headTitle>
			<xsl:for-each select="sp:intro">
				<sp:intro>
					<dk:optHTitle>
						<xsl:for-each select="dk:sTitle/sc:fullTitle">
							<sp:sTitle><xsl:value-of select="." /></sp:sTitle>
						</xsl:for-each>
					</dk:optHTitle>
<!--					<xsl:apply-templates select="dk:sTitle" mode="toOptHTitle"/>-->
					<xsl:apply-templates select="dk:comment"/>
				</sp:intro>
			</xsl:for-each>
			<xsl:apply-templates select="sp:subSection"/>
			<xsl:for-each select="sp:conclu">
				<sp:conclu>
					<dk:optHTitle>
						<xsl:for-each select="dk:sTitle/sc:fullTitle">
							<sp:sTitle><xsl:value-of select="." /></sp:sTitle>
						</xsl:for-each>
					</dk:optHTitle>
					<xsl:apply-templates select="dk:comment"/>
				</sp:conclu>
			</xsl:for-each>
		</dk:userGuide>
	</xsl:template>
	
	<!-- odRoot / webRoot -> aloneSectionMeta -->
	<xsl:template match="dk:aloneSectionMeta">
		<dk:aloneSectionMeta>
			<xsl:variable name="vfullTitle"><xsl:value-of select="sp:title"/></xsl:variable>
			<xsl:variable name="vshortTitle"><xsl:value-of select="sp:shortTitle"/></xsl:variable>
			<xsl:if test="sp:title | sp:shortTitle">
				<sp:title>
					<dk:headTitle>
						<xsl:choose>
							<xsl:when test="$vfullTitle">
								<sp:sTitle><xsl:value-of select="$vfullTitle" /></sp:sTitle>
							</xsl:when>
							<xsl:when test="$vshortTitle">
								<sp:sTitle><xsl:value-of select="$vshortTitle" /></sp:sTitle>
							</xsl:when>
							<xsl:otherwise>
								<sp:sTitle />
							</xsl:otherwise>
						</xsl:choose>
					</dk:headTitle>
				</sp:title>
			</xsl:if>
		</dk:aloneSectionMeta>
	</xsl:template>
	
	
	
	
	
	
	
	
	<!-- theory.model -->	
	<!-- regrouper les cplt en 1, titre des cplt, titre de theory -->
	<xsl:template match="dk:theory">
		<dk:theory>
			<xsl:apply-templates select="dk:title" mode="toHeadTitle"/>
			<xsl:apply-templates select="sp:content | sp:trainNote"/>
			<xsl:if test="sp:cplt">
				<sp:cplt>
					<dk:rTitle>
						<xsl:if test="sp:cplt/dk:cpltMeta/sp:title">
							<sp:rTitle>
								<dk:richTitle>
									<xsl:for-each select="sp:cplt/dk:cpltMeta/sp:title">
										<sc:para>
											<xsl:value-of select="."/>
										</sc:para>
									</xsl:for-each>
								</dk:richTitle>
							</sp:rTitle>
						</xsl:if>
					</dk:rTitle>
					<dk:content>
						<xsl:apply-templates select="sp:cplt/dk:content/sp:*" mode="addMetas"/>
					</dk:content>
				</sp:cplt>
			</xsl:if>
		</dk:theory>
	</xsl:template>
	
	
	<!-- module.model -->	
	<xsl:template match="dk:module">
		<dk:module>
			<xsl:apply-templates select="dk:title" mode="toHeadTitle"/>
			<xsl:for-each select="sp:*">
				<xsl:variable name="vName"><xsl:value-of select="local-name()"/></xsl:variable>
				<xsl:choose>
					<xsl:when test="$vName='binding'">
						<xsl:variable name="vRefUri"><xsl:value-of select="@sc:refUri"/></xsl:variable>
						<xsl:copy >
							<xsl:if test="$vRefUri">
								<xsl:attribute name="sc:refUri" ><xsl:value-of select="$vRefUri"/></xsl:attribute>
							</xsl:if>				
							<xsl:apply-templates select="dk:sTitle" mode="toHeadTitle"/>	
							<xsl:apply-templates select="dk:comment"/>
						</xsl:copy>
					</xsl:when>
					<xsl:when test="$vName='synthesis'">
						<xsl:copy >			
							<xsl:choose>
								<xsl:when test="dk:sTitle">
									<xsl:apply-templates select="dk:sTitle" mode="toOptHTitle"/>
								</xsl:when>
								<xsl:otherwise>
									<dk:optHTitle />
								</xsl:otherwise>
							</xsl:choose>	
							<xsl:apply-templates select="dk:content"/>
						</xsl:copy>
					</xsl:when>
					<xsl:otherwise>
						<xsl:apply-templates select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
		</dk:module>
	</xsl:template>
	
	
	<!-- exerciseMeta activityMeta -->
	<xsl:template match="dk:exerciseMeta | dk:activityMeta">
		<xsl:copy >
			<sp:title>
				<dk:headTitle>
					<sp:sTitle>
						<xsl:value-of select="sp:title"/>
					</sp:sTitle>
				</dk:headTitle>
			</sp:title>
			<xsl:comment><xsl:value-of select="sp:shortTitle" /></xsl:comment>
			<xsl:apply-templates select="sp:time"/>
		</xsl:copy>
	</xsl:template>
	
	<!-- demo simulation -->
	<xsl:template match="dk:demo  | dk:simulation">
		
		<xsl:copy >
			<xsl:apply-templates select="dk:title" mode="toHeadTitle"/>
			<xsl:apply-templates select="sp:*"/>
		</xsl:copy>
	</xsl:template>
	
	<!-- eval -->
	<xsl:template match="dk:eval">
		<dk:eval>
			<dk:optHTitle>
				<xsl:choose>
					<xsl:when test="dk:evalMeta/sp:title">
						<sp:sTitle><xsl:value-of select="dk:evalMeta/sp:title"/></sp:sTitle>
						<xsl:comment><xsl:value-of select="dk:evalMeta/sp:sTitle" /></xsl:comment>
					</xsl:when>
					<xsl:when test="dk:evalMeta/sp:sTitle">
						<sp:sTitle><xsl:value-of select="dk:evalMeta/sp:sTitle"/></sp:sTitle>
					</xsl:when>
				</xsl:choose>
			</dk:optHTitle>
			<xsl:for-each select="sp:*">
				<xsl:variable name="vName"><xsl:value-of select="local-name(.)"/></xsl:variable>
				<xsl:choose>
					<xsl:when test="$vName='synthesis'">
						<xsl:copy >		
							<xsl:choose>
								<xsl:when test="dk:sTitle">
									<xsl:apply-templates select="dk:sTitle" mode="toOptHTitle"/>
								</xsl:when>
								<xsl:otherwise>
									<dk:optHTitle />
								</xsl:otherwise>
							</xsl:choose>		
							<xsl:apply-templates select="dk:comment"/>
						</xsl:copy>
					</xsl:when>
					<xsl:otherwise>
						<xsl:apply-templates select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
		</dk:eval>
	</xsl:template>
	
	
	<!-- urlM subdata docMeta -> resM -->
	<xsl:template match="dk:docMeta">
		<dk:resM>
			<sp:title>
				<dk:rTitle>
					<sp:rTitle>
						<dk:richTitle>
							<sc:para xml:space="preserve"><xsl:value-of select="sp:title" /></sc:para>
						</dk:richTitle>
					</sp:rTitle>
					
				</dk:rTitle>
			</sp:title>
			<xsl:comment>
				Cette structure n’est plus reconnue
				<xsl:copy>
					<xsl:apply-templates select="sp:desc" mode="nocomments"/>
				</xsl:copy>
			</xsl:comment>
		</dk:resM>
	</xsl:template>
	
	
	
	
	
	
	<!-- binaries : scr.seq -> seq -->
	<xsl:template match="dk:screenSeqMeta/sp:title">
			<sp:title>
				<dk:rTitle>
					<sp:rTitle>
						<dk:richTitle>
							<sc:para xml:space="preserve"><xsl:value-of select="." /></sc:para>
						</dk:richTitle>
					</sp:rTitle>
					
				</dk:rTitle>
			</sp:title>
	</xsl:template>
	
	
	
	
	<!-- binaries : scr.png -> png etc -->
	<xsl:template match="sfm:scr.swf">
		<sfm:swf>
			<xsl:apply-templates />
		</sfm:swf>
	</xsl:template>
	<xsl:template match="sfm:scr.flv">
		<sfm:flv>
			<xsl:apply-templates />
		</sfm:flv>
	</xsl:template>
	<xsl:template match="sfm:scr.png_scr.gif">
		<xsl:variable name="vIsGif"><xsl:value-of select="substring-after($pCurrentItemUri,'.gif')"/></xsl:variable>
		<xsl:choose>
			<xsl:when test="$vIsGif">
				<sfm:gif>
					<xsl:apply-templates mode="toImgM" />
				</sfm:gif>
			</xsl:when>
			<xsl:otherwise>
				<sfm:png>
					<xsl:apply-templates mode="toImgM" />
				</sfm:png>
			</xsl:otherwise>
		</xsl:choose>
		
	</xsl:template>
	<xsl:template match="sfm:icon.png_icon.gif">
		<xsl:variable name="vIsGif"><xsl:value-of select="substring-after($pCurrentItemUri,'.gif')"/></xsl:variable>
		<xsl:choose>
			<xsl:when test="$vIsGif">
				<sfm:gif>
					<xsl:apply-templates mode="toImgM" />
				</sfm:gif>
			</xsl:when>
			<xsl:otherwise>
				<sfm:png>
					<xsl:apply-templates mode="toImgM" />
				</sfm:png>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	
	<!-- binaries : imgMeta to resM cas de :
	ods
	odg
	jpg -->
	<xsl:template match="sfm:odg/dk:imgMeta | sfm:ods/dk:imgMeta | sfm:jpg_jpeg/dk:imgMeta ">
		<dk:resM>
			<sp:title>
				<dk:rTitle>
					<sp:rTitle>
						<dk:richTitle>
							<sc:para xml:space="preserve"><xsl:value-of select="sp:title" /></sc:para>
						</dk:richTitle>
					</sp:rTitle>
				</dk:rTitle>
			</sp:title>
		</dk:resM>
	</xsl:template>
	
	<!-- binaries : imgM cas de :
	imgMeta : png gif
	screenShotMeta scr.png scr.gif
	sTitle : icon.png icon.gif
	-->
	<xsl:template match="sfm:png/dk:imgMeta | sfm:gif/dk:imgMeta ">
		<dk:imgM>
			<sp:title>
				<dk:rTitle>
					<sp:rTitle>
						<dk:richTitle>
							<sc:para xml:space="preserve"><xsl:value-of select="sp:title" /></sc:para>
						</dk:richTitle>
					</sp:rTitle>
				</dk:rTitle>
			</sp:title>
			<sp:type>oth</sp:type>
		</dk:imgM>
	</xsl:template>
	
	<xsl:template match="dk:screenShotMeta " mode="toImgM">
		<dk:imgM>
			<sp:title>
				<dk:rTitle>
					<sp:rTitle>
						<dk:richTitle>
							<sc:para xml:space="preserve"><xsl:value-of select="sp:title" /></sc:para>
						</dk:richTitle>
					</sp:rTitle>
				</dk:rTitle>
			</sp:title>
			<sp:type>scr</sp:type>
		</dk:imgM>
	</xsl:template>
	
	<xsl:template match="dk:sTitle "   mode="toImgM" > <!-- icones -->
		<dk:imgM>
			<sp:title>
				<dk:rTitle>
					<sp:rTitle>
						<dk:richTitle>
							<sc:para xml:space="preserve"><xsl:value-of select="sc:fullTitle" /></sc:para>
						</dk:richTitle>
					</sp:rTitle>
				</dk:rTitle>
			</sp:title>
			<sp:type>scr</sp:type>
		</dk:imgM>
	</xsl:template>
	
	<!-- binaries : mediaM cas de :
	swf -> imgMeta
	screenMovieFlash / Flv -> screenMovieMeta
	flv -> pas de meta
	pdf -> docMeta
	-->
	<xsl:template match="sfm:swf/dk:imgMeta | sfm:pdf/dk:docMeta | dk:screenMovieMeta | dk:screenMovieMeta">
		<dk:mediaM>
			<sp:title>
				<dk:rTitle>
					<sp:rTitle>
						<dk:richTitle>
							<sc:para xml:space="preserve"><xsl:value-of select="sp:title" /></sc:para>
						</dk:richTitle>
					</sp:rTitle>
				</dk:rTitle>
			</sp:title>
			
			<xsl:comment>
				Cette structure n’est plus reconnue
				<xsl:copy>
					<xsl:apply-templates select="sp:desc" mode="nocomments"/>
				</xsl:copy>
			</xsl:comment>
			<!--<xsl:for-each select="sp:desc">
				<sp:alternative>
					<xsl:apply-templates />
				</sp:alternative>
			</xsl:for-each> -->
		</dk:mediaM>
	</xsl:template>
	
	
	
	
	
	
	
	<!--  SWAD -->
	
		<!-- sec.model -->
	<xsl:template match="dk:sec">
		<dk:sec>
			<xsl:apply-templates select="@*"/>
			<xsl:choose>
				<xsl:when test="dk:sTitle">
					<xsl:apply-templates select="dk:sTitle" mode="toRTitle"/>
				</xsl:when>
				<xsl:otherwise>
					<dk:rTitle/>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:apply-templates select="sp:co"/>
		</dk:sec>
	</xsl:template>
	

	
	
	
	
	
	<!--  Utils -->
	
	<!-- Titre simple en titre riche texte cas de :
	theory : partMeta de cplt
	imgM : subdata title
	mediaM : subdata title
	resM : subdata title
	linkSection : meta + parMeta de doc-> fait direct dans le template de extra car dk:rTitle est obligatoire
	stepList : partMeta de alt
	part : meta
	step : partMeta de extras -> fait direct dans le template de extra car dk:rTitle est obligatoire
	-->
	<xsl:template match="dk:sTitle" mode="toRTitle">
		<dk:rTitle>
			<sp:rTitle>
				<dk:richTitle>
					<sc:para xml:space="preserve"><xsl:apply-templates select="sc:fullTitle/node()" /></sc:para>
				</dk:richTitle>
			</sp:rTitle>
		</dk:rTitle>
	</xsl:template>
	
	<!-- Titre simple en titre riche + filtre dans les balises d’intentionnalité cas de : 
	logistics
	startTrain
	comment
	content
	-->
	<!-- OK -->
	<xsl:template match="dk:sTitle" mode="toBlocTi">
		<dk:blocTi>
			<sp:filters><dk:filter/></sp:filters>
			<sp:rTitle>
				<dk:richTitle>
					<sc:para xml:space="preserve"><xsl:apply-templates select="sc:fullTitle/node()" /></sc:para>
				</dk:richTitle>
			</sp:rTitle>
		</dk:blocTi>
	</xsl:template>
	
	<!-- Titre simple en titre riche  cas de : 
	module : partMeta de binding
	-->
	<!-- OK -->
	<xsl:template match="dk:sTitle" mode="toHeadTitle">
		<dk:headTitle>
			<sp:sTitle><xsl:value-of select="sc:fullTitle" /></sp:sTitle>
		</dk:headTitle>
	</xsl:template>
	
	
	<!-- Titre simple en titre OPTIONNEL porteur de page (texte + string), cas de :
	module : parMeta de synthesis
	-->
	<xsl:template match="dk:sTitle" mode="toOptHTitle">
		<xsl:variable name="vfullTitle"><xsl:value-of select="sc:fullTitle"/></xsl:variable>
		<dk:optHTitle>
			<sp:sTitle><xsl:value-of select="$vfullTitle" /></sp:sTitle>
		</dk:optHTitle>
	</xsl:template>



	<!-- Titre long/court en titre porteur de page (texte + string), cas de :
	exerciseMeta : subdata title
	activityMeta : subdata title
	screenMeta : subdata title
	stepListM : subdata title
	themeM : subdata  title| pas de migration
	theory : meta
	demo : meta
	section : meta
	aloneSectionMeta : subdata title 
	userGuide : meta
	simulation : meta
	logistics : meta
	module : meta, partMeta de binding
	-->
	<xsl:template match="dk:title" mode="toHeadTitle">
		<xsl:variable name="vfullTitle"><xsl:value-of select="sc:fullTitle"/></xsl:variable>
		<xsl:variable name="vshortTitle"><xsl:value-of select="sc:shortTitle"/></xsl:variable>
		<dk:headTitle>
			<xsl:choose>
				<xsl:when test="$vfullTitle">
					<sp:sTitle><xsl:value-of select="$vfullTitle" /></sp:sTitle>
				</xsl:when>
				<xsl:when test="$vshortTitle">
					<sp:sTitle><xsl:value-of select="$vshortTitle" />
					</sp:sTitle>
				</xsl:when>
				<xsl:otherwise>
					<sp:sTitle />
				</xsl:otherwise>
			</xsl:choose>
		</dk:headTitle>
		<!-- titre court en commentaire si jamais il y a un titre long -->
		<xsl:if test="$vfullTitle and $vshortTitle">
			<xsl:comment><xsl:value-of select="$vshortTitle" /></xsl:comment>
		</xsl:if>
	</xsl:template>


	<!-- Titre long/court en titre OPTIONNEL porteur de page (texte + string), cas de :
	userGuide : partMeta de intro conclu
	startTrain : meta
	eval : meta
	-->
	
	<xsl:template match="dk:title" mode="toOptHTitle">
		<xsl:variable name="vfullTitle"><xsl:value-of select="sc:fullTitle"/></xsl:variable>
		<xsl:variable name="vshortTitle"><xsl:value-of select="sc:shortTitle"/></xsl:variable>
		<xsl:choose>
			<xsl:when test="$vfullTitle">
				<dk:optHTitle>
					<sp:sTitle><xsl:value-of select="$vfullTitle" /></sp:sTitle>
				</dk:optHTitle>
			</xsl:when>
			<xsl:when test="$vshortTitle">
				<dk:optHTitle>
					<sp:sTitle><xsl:value-of select="$vshortTitle" /></sp:sTitle>
				</dk:optHTitle>
			</xsl:when>
			<xsl:otherwise/>
		</xsl:choose>
		<!-- titre court en commentaire si jamais il y a un titre long -->
		<xsl:if test="$vfullTitle and $vshortTitle">
			<xsl:comment><xsl:value-of select="$vshortTitle" /></xsl:comment>
		</xsl:if>
	</xsl:template>
	
	<!-- ### 
		# Cas général : on copie
		### -->
<!--<xsl:template match="@*|node()">
		<xsl:copy>
			<xsl:apply-templates select="@*|node()"/>
		</xsl:copy>
	</xsl:template>--> 
		
</xsl:stylesheet>
